﻿using System.Collections.ObjectModel;
using System.Drawing;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WmsServerEdition;

namespace WmsPlugins
{
    public class FileBitmapCacheWmsLayerPlugin : WmsLayerPlugin
    {

        // This method gets called on every map request sent to the server.  In the parameters we pass the
        // map request which includes the bounding box, image size etc.  We also pass you the map configuration
        // which includes all the static layers.  In this method you can make any data changes or do anything
        // dynamic you want
        protected override Bitmap GetMapCore(GetMapRequest getMapRequest, MapConfiguration mapConfiguration, System.Web.HttpContext context)
        {
            return base.GetMapCore(getMapRequest, mapConfiguration, context);
        }

        // In this method you need to return the name of the Layer that WMS will expose.
        // You will use this name on the client to specify the layer you want to consume
        protected override string GetNameCore()
        {
            return "FileBitmapCache WmsLayer";
        }

        // In this method you need to return the projections that are supported by your data.
        // It is your responsability to project the data in the MapConfiguration for each projection
        // type you specify here.
        protected override Collection<string> GetProjectionsCore()
        {
            return new Collection<string> { "EPSG:4326" };
        }

        // In this method you need to return the bounding box of the layer.
        protected override RectangleShape GetBoundingBoxCore(string crs)
        {
            return new RectangleShape(-126.826171875, 57.104766845702, -70.83984375, 18.960235595702); // we can set it as the maximum extents.
        }

        protected override MapConfiguration GetMapConfigurationCore(string style, string crs)
        {
            var mapConfiguration = new MapConfiguration();
            GdiPlusRasterLayer layer = new GdiPlusRasterLayer(@"D:\Data\Tiff\World.tif");
            mapConfiguration.Layers.Add("WorldLayerName", layer);
            var fileCache = new FileBitmapTileCache("d:\\wmscache");
            fileCache.TileAccessMode = TileAccessMode.ReadOnly; // It means that the Cache will not save the tile.
            fileCache.CacheId = "wmscache";
            mapConfiguration.TileCache = fileCache; 

            return mapConfiguration;
        }
    }
}
